@@ -98,7 +98,9 @@ def _cli_main(parser: argparse.ArgumentParser, args_list: List[str]):
         os.makedirs(cache_dir, exist_ok=True)
         storage = AzureBlobStorage(cache_dir,
                                    config['data_azure_storage_container_uri'],
-                                   config['data_azure_storage_path'])
+                                   config['data_azure_storage_path'] 
+                                   if 'data_azure_storage_path' in config
+                                        else None)
 
         storage_connection = ""
         if 'data_azure_storage_connection_string' in config:
